#!/usr/bin/python3
# This script will monitor list.txt and program the usb device when
# a usb gadget is plugged in.
import time
import subprocess
import os
import threading
from watchdog.observers import Observer
from watchdog.events import FileSystemEventHandler

base_path = "/home/lab/flasher"
list_path = "/home/lab/flasher/list.txt"
img_file  = "/home/lab/flasher/bone-debian-9.3-iot-armhf-2018-03-05-4gb.img"

TIMEOUT   = 1200

running_threads = []


def ddcopy(last_line):
    """
    Funtion that will copy .img file to usb gadget
    """
    os.system('sudo dd if='+img_file+' of=/dev/'+last_line.rstrip())


def clean_up_threads():
    """
    Clean up any threads that exceed the timeout value or have completed execution
    """
    for thread in running_threads:
        if not thread.is_alive():
            running_threads.remove(thread)

class MyHandler(FileSystemEventHandler):

    def on_modified(self, event):
        if event.src_path == list_path:
            with open(list_path, "r") as f:
                last_line = f.readlines()[-1]
                print(last_line.rstrip())

            new_thread = threading.Thread(target = ddcopy, args = (last_line,))
            running_threads.append(new_thread)
            new_thread.start()

            print('dd if='+img_file+' of=/dev/'+last_line+' executed')


if __name__ == "__main__":
    event_handler = MyHandler()
    observer      = Observer()
    observer.schedule(event_handler, path=base_path, recursive=False)
    observer.start()

    try:
        while True:
            time.sleep(10)
            clean_up_threads()
    except KeyboardInterrupt:
        observer.stop()

    observer.join()

    if not running_threads.empty():
        raise IOError("Not all threads were done when program terminated")


